import { NextResponse } from 'next/server';
import type { NextRequest } from 'next/server';
import { updateUserPushToken } from '~/server/functions';
import { middleware } from "~/middleware";

type Data = {
  userId: string;
  pushToken: string;
};

export const POST = async (request: NextRequest) => {
  const middlewareResponse = await middleware(request);
  if (middlewareResponse) return middlewareResponse;
  try {
    const { userId, pushToken } = await request.json() as Data;
    console.log('Received request:', { userId, pushToken });

    console.log('Updating push token for user:', userId);
    await updateUserPushToken(parseInt(userId), pushToken);

    console.log('Push token updated successfully');
    return NextResponse.json({ message: "Push token updated successfully" });
  } catch (error) {
    console.error('Error in updatePushToken:', error);
    return NextResponse.json({ message: "Error updating push token" }, { status: 500 });
  }
};
